@@ -22,11 +22,12 @@
 #include "akonadiconnection.h"
 #include "handlerhelper.h"
 #include "storage/datastore.h"
+#include "storage/itemqueryhelper.h"
 #include "storage/transaction.h"
 #include "storage/selectquerybuilder.h"
 #include "entities.h"
 
-#include "../../libs/imapparser_p.h"
+#include "imapstreamparser.h"
 
 using namespace Akonadi;
 
@@ -34,24 +35,19 @@ Link::Link(bool create) : Handler(), mCreateLinks( create )
 {
 }
 
-bool Link::handleLine(const QByteArray & line)
+bool Link::parseStream()
 {
-  QByteArray tmp;
-  int pos = ImapParser::parseString( line, tmp ); // skip tag
-  pos = ImapParser::parseString( line, tmp, pos ); // skip command
-
-  pos = ImapParser::parseString( line, tmp, pos );
-  const Location collection = HandlerHelper::collectionFromIdOrName( tmp );
+  QByteArray tmp = m_streamParser->readString();
+  const Collection collection = HandlerHelper::collectionFromIdOrName( tmp );
   if ( !collection.isValid() )
     return failureResponse( "No valid collection specified" );
 
-  ImapSet set;
-  ImapParser::parseSequenceSet( line, set, pos );
+  ImapSet set = m_streamParser->readSequenceSet();
   if ( set.isEmpty() )
     return failureResponse( "No valid sequence set specified" );
 
   SelectQueryBuilder<PimItem> qb;
-  imapSetToQuery( set, true, qb );
+  ItemQueryHelper::itemSetToQuery( set, qb );
   if ( !qb.exec() )
     return failureResponse( "Unable to execute item query" );
 
@@ -79,3 +75,5 @@ bool Link::handleLine(const QByteArray & line)
 
   return successResponse( "LINK complete" );
 }
+
+#include "link.moc"
