@@ -32,6 +32,7 @@
 #include "xdgbasedirs_p.h"
 #include "akdebug.h"
 #include "parthelper.h"
+#include "libs/protocol_p.h"
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
@@ -254,7 +255,7 @@ bool Akonadi::DataStore::cleanupCollection(Collection &collection)
     cleanupPimItem( item );
 
   // delete collection mimetypes
-  removeMimeTypesForCollection( collection.id() );
+  collection.clearMimeTypes();
   Collection::clearPimItems( collection.id() );
 
   // delete attributes
@@ -323,7 +324,8 @@ bool Akonadi::DataStore::renameCollection( Collection & collection, qint64 newPa
   if ( !collection.update() )
     return false;
 
-  mNotificationCollector->collectionChanged( collection );
+  QList<QByteArray> changes = QList<QByteArray>() << "PARENT" << AKONADI_PARAM_NAME;
+  mNotificationCollector->collectionChanged( collection, changes );
   return true;
 }
 
@@ -358,11 +360,6 @@ bool DataStore::appendMimeTypeForCollection( qint64 collectionId, const QStringL
   return true;
 }
 
-bool Akonadi::DataStore::removeMimeTypesForCollection(qint64 collectionId)
-{
-  return Collection::clearMimeTypes( collectionId );
-}
-
 
 void DataStore::activeCachePolicy(Collection & col)
 {
@@ -542,7 +539,7 @@ bool DataStore::addCollectionAttribute(const Collection & col, const QByteArray
   if ( !attr.insert() )
     return false;
 
-  mNotificationCollector->collectionChanged( col );
+  mNotificationCollector->collectionChanged( col, QList<QByteArray>() << key );
   return true;
 }
 
@@ -559,7 +556,7 @@ bool Akonadi::DataStore::removeCollectionAttribute(const Collection & col, const
       return false;
   }
 
-  mNotificationCollector->collectionChanged( col );
+  mNotificationCollector->collectionChanged( col, QList<QByteArray>() << key );
   return true;
 }
 
